@@ -23,38 +23,50 @@
 
 #include <QWidget>
 #include <QGridLayout>
-#include <QLabel>
+#include <QTextBrowser>
 #include <QPushButton>
 
+#include "pumpcontroller.h"
 #include "composer.h"
+#include "mischelpers.h"
+#include "timestamp.h"
 
 class Commenter : public QWidget
 {
     Q_OBJECT
 
 public:
-    explicit Commenter(QWidget *parent = 0);
+    explicit Commenter(PumpController *pumpController, QWidget *parent = 0);
     ~Commenter();
 
-    void setCommments(QString comments);
+    void setComments(QVariantList commentsList);
     
 signals:
     void commentSent(QString comment);
+    void allCommentsRequested();
+
     
 public slots:
     void setMinimumMode();
     void setFullMode();
 
+    void requestAllComments();
+
     void sendComment();
 
 private:
     QGridLayout *mainLayout;
 
-    QLabel *commentsLabel;
+    QTextBrowser *commentsTextBrowser;
+    QPushButton *showAllCommentsButton;
+
 
     Composer *commentComposer;
     QPushButton *commentButton;
-    
+    QPushButton *cancelButton;
+
+
+    PumpController *pController;
 };
 
 #endif // COMMENTER_H
