@@ -21,65 +21,76 @@
 #include "composer.h"
 
 
-Composer::Composer()
+Composer::Composer(bool forPublisher)
 {
+    this->forPublisher = forPublisher;
+
     this->setAcceptRichText(true);
     this->setTabChangesFocus(true);
-    //this->setCursorWidth(2);
-
-    this->setToolTip(tr("Type a message here to post it"));
 
     mainLayout = new QGridLayout();
 
-    startConversationLabel = new QLabel(tr("Click here or press Control+N to post a note..."));
+    if (this->forPublisher)
+    {
+        this->setToolTip(tr("Type a message here to post it"));
 
 
-    toolsMenu = new QMenu("tools-menu");
-    toolsMenu->addAction(QIcon::fromTheme(""),
-                         tr("Normal"),
-                         this,
-                         SLOT(makeNormal()));
-    toolsMenu->addAction(QIcon::fromTheme("format-text-bold"),
-                         tr("Bold"),
-                         this,
-                         SLOT(makeBold()));
-    toolsMenu->addAction(QIcon::fromTheme("format-text-italic"),
-                         tr("Italic"),
-                         this,
-                         SLOT(makeItalic()));
-    toolsMenu->addAction(QIcon::fromTheme(""),
-                         tr("Bold + Italic"),
-                         this,
-                         SLOT(makeBoldAndItalic()));
-    toolsMenu->addAction(QIcon::fromTheme("format-text-underline"),
-                         tr("Underline"),
-                         this,
-                         SLOT(makeUnderline()));
-    toolsMenu->addSeparator();
-    toolsMenu->addAction(QIcon::fromTheme("insert-link"),
-                         tr("Make a link"),
-                         this,
-                         SLOT(makeLink()));
-    /*
-    toolsMenu->addAction(QIcon::fromTheme("insert-image"),
-                         tr("Insert an image from a web site"),
-                         this,
-                         SLOT(insertImage()));
-    */
-    toolsMenu->addSeparator();
-    toolsMenu->addAction(QIcon::fromTheme("dialog-cancel"),
-                         tr("Cancel Post"),
-                         this,
-                         SLOT(cancelPost()));
+        startConversationLabel = new QLabel(tr("Click here or press Control+N to post a note..."));
 
-    toolsButton = new QPushButton(QIcon::fromTheme("format-list-ordered"), tr("&F", "F for formatting, translate accordingly"));
-    toolsButton->setMenu(toolsMenu);
-    toolsButton->setToolTip(tr("Text Formatting Options"));
-    toolsButton->setHidden(true); // Hidden on startup (Publisher in miniMode)
 
-    mainLayout->addWidget(startConversationLabel, 0, 0, 1, 1, Qt::AlignLeft | Qt::AlignVCenter);
-    mainLayout->addWidget(toolsButton,            0, 1, 1, 1, Qt::AlignRight | Qt::AlignTop);
+        toolsMenu = new QMenu("tools-menu");
+        toolsMenu->addAction(QIcon::fromTheme(""),
+                             tr("Normal"),
+                             this,
+                             SLOT(makeNormal()));
+        toolsMenu->addAction(QIcon::fromTheme("format-text-bold"),
+                             tr("Bold"),
+                             this,
+                             SLOT(makeBold()));
+        toolsMenu->addAction(QIcon::fromTheme("format-text-italic"),
+                             tr("Italic"),
+                             this,
+                             SLOT(makeItalic()));
+        toolsMenu->addAction(QIcon::fromTheme(""),
+                             tr("Bold + Italic"),
+                             this,
+                             SLOT(makeBoldAndItalic()));
+        toolsMenu->addAction(QIcon::fromTheme("format-text-underline"),
+                             tr("Underline"),
+                             this,
+                             SLOT(makeUnderline()));
+        toolsMenu->addSeparator();
+        toolsMenu->addAction(QIcon::fromTheme("insert-link"),
+                             tr("Make a link"),
+                             this,
+                             SLOT(makeLink()));
+        /*
+        toolsMenu->addAction(QIcon::fromTheme("insert-image"),
+                             tr("Insert an image from a web site"),
+                             this,
+                             SLOT(insertImage()));
+        */
+        toolsMenu->addSeparator();
+        toolsMenu->addAction(QIcon::fromTheme("dialog-cancel"),
+                             tr("Cancel Post"),
+                             this,
+                             SLOT(cancelPost()));
 
+        toolsButton = new QPushButton(QIcon::fromTheme("format-list-ordered"), tr("&F", "F for formatting, translate accordingly"));
+        toolsButton->setMenu(toolsMenu);
+        toolsButton->setToolTip(tr("Text Formatting Options"));
+        toolsButton->setHidden(true); // Hidden on startup (Publisher in miniMode)
+
+
+        mainLayout->addWidget(startConversationLabel, 0, 0, 1, 1, Qt::AlignLeft | Qt::AlignVCenter);
+        mainLayout->addWidget(toolsButton,            0, 1, 1, 1, Qt::AlignRight | Qt::AlignTop);
+    }
+    else // then, for commenter
+    {
+        this->setToolTip(tr("Type a comment here.\n"
+                            "You can press Control+Enter to send the comment\n"
+                            "with the keyboard, or ESC to cancel."));
+    }
 
     this->setLayout(mainLayout);
 
@@ -97,9 +108,12 @@ void Composer::erase()
 {
     this->clear();
 
-    startConversationLabel->show();
+    if (this->forPublisher)
+    {
+        startConversationLabel->show();
 
-    toolsButton->hide();  /// FIXME: maybe move this line to focusOutEvent
+        toolsButton->hide();  /// FIXME: maybe move this line to focusOutEvent
+    }
 }
 
 
@@ -109,10 +123,13 @@ void Composer::erase()
  */
 void Composer::focusInEvent(QFocusEvent *event)
 {
-    emit focusReceived(); // inform Publisher() that we are focused
+    emit focusReceived(); // inform Publisher() or Commenter() that we have focused
 
-    startConversationLabel->hide(); // hide placeholder message
-    toolsButton->show();
+    if (this->forPublisher)
+    {
+        startConversationLabel->hide(); // hide placeholder message
+        toolsButton->show();
+    }
 
     QTextEdit::focusInEvent(event); // process standard event: allows context menu
 
