@@ -36,7 +36,7 @@ class Composer : public QTextEdit
     Q_OBJECT
 
 public:
-    Composer();
+    Composer(bool forPublisher);
     ~Composer();
 
     void erase();
@@ -69,6 +69,7 @@ private:
     QPushButton *toolsButton;
     QMenu *toolsMenu;
 
+    bool forPublisher;
 };
 
 #endif // COMPOSER_H
