@@ -75,27 +75,26 @@ ContactCard::ContactCard(PumpController *pumpController,
     this->contactID = contactData.value("id");
 
     tmpLabel = new QLabel();
-    tmpLabel->setText(QString("<%1>\n"
-                              "%2  /  %3").arg(contactID)
-                                          .arg(contactData.value("follower") == "true" ? "Follower" : "*")
-                                          .arg(contactData.value("following") == "true" ? "Following": "*"));
+    tmpLabel->setText(QString("<%1>\n").arg(contactID)
+                      + tr("Hometown") + QString(": %2").arg(contactData.value("hometown")));
     tmpLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
+    tmpLabel->setToolTip(contactData.value("bio")); // kinda tmp...
 
 
     centerLayout->addWidget(nameLabel);
     centerLayout->addWidget(tmpLabel);
 
+    followButton = new QPushButton("--");
+    followButton->setFlat(true);    
     if (contactData.value("following") == "false")
     {
-        followButton = new QPushButton(QIcon::fromTheme("list-add"), tr("Follow"));
+        this->setButtonToFollow();
     }
     else
     {
-        followButton = new QPushButton(QIcon::fromTheme("list-remove"), tr("Stop following"));
-        connect(followButton, SIGNAL(clicked()),
-                this, SLOT(unfollowContact()));
+        this->setButtonToUnfollow();
     }
-    followButton->setFlat(true);
+
 
     mainLayout->addWidget(avatarLabel,  1);  // Stretch 1/8
     mainLayout->addLayout(centerLayout, 6);  // Stretch 6/8
@@ -114,12 +113,40 @@ ContactCard::~ContactCard()
 }
 
 
+
+void ContactCard::setButtonToFollow()
+{
+    followButton->setIcon(QIcon::fromTheme("list-add"));
+    followButton->setText(tr("Follow"));
+    connect(followButton, SIGNAL(clicked()),
+            this, SLOT(followContact()));
+}
+
+
+void ContactCard::setButtonToUnfollow()
+{
+    followButton->setIcon(QIcon::fromTheme("list-remove"));
+    followButton->setText(tr("Stop following"));
+    connect(followButton, SIGNAL(clicked()),
+            this, SLOT(unfollowContact()));
+}
+
+
 /**************************************************************************/
 /******************************** SLOTS ***********************************/
 /**************************************************************************/
 
 
+
+void ContactCard::followContact()
+{
+    this->pController->followContact(this->contactID);
+    this->setButtonToUnfollow();
+}
+
+
 void ContactCard::unfollowContact()
 {
     this->pController->unfollowContact(this->contactID);
+    this->setButtonToFollow();
 }
