@@ -113,7 +113,7 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     rightLayout = new QVBoxLayout();
 
     this->publisherType = settings.value("publisherType", 0).toInt(); // FIXME
-    publisher = new Publisher(publisherType);
+    publisher = new Publisher(pumpController, publisherType);
 
 
     timeLine = new TimeLine(pumpController, this);
@@ -133,21 +133,36 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     messageListScrollArea->setWidgetResizable(true);
 
 
+    // The contact list has its own tabs with its own scroll areas
     contactList = new ContactList(pumpController, this);
-    contactListScrollArea = new QScrollArea();
-    contactListScrollArea->setWidget(contactList); // Make contact list scrollable
-    contactListScrollArea->setWidgetResizable(true);
+
 
     tabWidget = new QTabWidget();
     tabWidget->addTab(timeLineScrollArea,
                       QIcon::fromTheme("view-list-details"),
                       tr("&Timeline"));
+    tabWidget->setTabToolTip(0, tr("The main timeline"));
+    tabWidget->addTab(new QWidget(),
+                      QIcon::fromTheme("user-home"),
+                      tr("Activity"));
+    tabWidget->setTabToolTip(1, tr("Your own posts"));
+    tabWidget->addTab(new QWidget(),
+                      QIcon::fromTheme("folder-favorites"),
+                      tr("Favorites"));
+    tabWidget->setTabToolTip(2, tr("Your favorited posts"));
     tabWidget->addTab(messageListScrollArea,
                       QIcon::fromTheme("mail-message"),
                       tr("&Messages"));
-    tabWidget->addTab(contactListScrollArea,
+    tabWidget->setTabToolTip(3, tr("Messages sent explicitly to you"));
+    tabWidget->addTab(contactList,
                       QIcon::fromTheme("system-users"),
                       tr("&Contacts"));
+    tabWidget->setTabToolTip(4, tr("The people you follow, and the ones who follow you"));
+
+    // TMP/FIXME: disable tabs which are not done yet
+    tabWidget->setTabEnabled(1, false); // activity
+    tabWidget->setTabEnabled(2, false); // favorites
+    tabWidget->setTabEnabled(3, false); // messages
 
     rightLayout->addWidget(publisher, 1); // stretch 1/10
     rightLayout->addWidget(tabWidget, 9); // stretch 9/10
@@ -206,10 +221,18 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
             this, SLOT(storeImage(QByteArray,QUrl)));
     connect(pumpController, SIGNAL(aspectListReceived(QVariantList)),
             this, SLOT(updateAspectList(QVariantList)));
+
     connect(pumpController, SIGNAL(timeLineReceived(QVariantList,int,QString,QString)),
             timeLine, SLOT(setTimeLineContents(QVariantList,int,QString,QString)));
-    connect(pumpController, SIGNAL(contactListReceived(QVariantList)),
-            contactList, SLOT(setContactListContents(QVariantList)));
+
+    connect(pumpController, SIGNAL(likesReceived(QVariantList,QString)),
+            timeLine, SLOT(setLikesInPost(QVariantList,QString)));
+    connect(pumpController, SIGNAL(commentsReceived(QVariantList,QString)),
+            timeLine, SLOT(setCommentsInPost(QVariantList,QString)));
+
+    connect(pumpController, SIGNAL(contactListReceived(QString,QVariantList)),
+            contactList, SLOT(setContactListContents(QString,QVariantList)));
+
     connect(pumpController, SIGNAL(showNotification(QString)),
             fdNotifier, SLOT(showMessage(QString)));
 
@@ -217,10 +240,6 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     connect(pumpController, SIGNAL(currentJobChanged(QString)),
             this, SLOT(setStatusBarMessage(QString)));
 
-    //// Outgoing
-    connect(publisher, SIGNAL(sharePost(QString)),
-            pumpController, SLOT(post(QString)));
-
 
 
     // Don't set PumpController in motion if no User ID is set!
@@ -732,17 +751,9 @@ void MainWindow::updateAspectList(QVariantList aspectList)
 
 void MainWindow::updateTimelines()
 {
-    pumpController->getTimeline();
+    pumpController->getTimeline(0);
     // received timeline data will come in a SIGNAL()
 
-/*
-    if (showNotifications != 2) // If notifications are enabled (FD.org or Qt's)
-    {
-        fdNotifier->showMessage("Updating <u>timelines</u>.\n"
-                                "Temporary <b>dummy</b> notification!\n"
-                                "<a href=\"http://jancoding.wordpress.com/dianara\">Go to Dianara's website</a>");
-    }
-*/
 
     qDebug() << "Updated timelines by menu or after:" << this->updateInterval << "min";
 }
@@ -773,6 +784,11 @@ void MainWindow::notifyTimelineUpdate(int newPostCount)
     {
         this->setStatusBarMessage(tr("Timeline updated. No new posts."));
     }
+
+
+    // In either case, restart update timer, so every manual update of timeline
+    this->updateTimer->stop();  // will postpone the auto-update
+    this->updateTimer->start();
 }
 
 
@@ -887,18 +903,20 @@ void MainWindow::visitWebSite()
 void MainWindow::aboutDianara()
 {
     QMessageBox::about(this, tr("About Dianara"),
-                       "<b>Dianara v0.5</b><br>"
+                       "<b>Dianara v0.6</b><br>"
                        "Copyright 2012-2013  JanKusanagi<br>"
-                       "<a href=\"http://dianara.nongnu.org\">"
-                       "http://dianara.nongnu.org</a><br>"
                        "<a href=\"http://jancoding.wordpress.com/dianara\">"
-                       "http://jancoding.wordpress.com/dianara</a><br><br><br>"
-                       + tr("Dianara is a pump.io social networking client.<br><br>"
-                            "It is work in progress. Right now only the "
-                            "interface and some basic capabilities: posting text, "
-                            "showing timeline, linking/commenting/sharing/deleting posts, "
-                            "and contact listing."
-                            "<br><br>"));
+                       "http://jancoding.wordpress.com/dianara</a><br>"
+                       "<a href=\"http://dianara.nongnu.org\">"
+                       "http://dianara.nongnu.org</a><br><br>"
+                       + tr("Dianara is a pump.io social networking client.")
+                       + "<br><br>"
+                       + tr("With Dianara you can see your timeline, create new posts, "
+                            "like/comment/share/delete posts, "
+                            "see your contacts and follow new people.")
+                       + "<br><br><br>"
+                       + tr("English translation by JanKusanagi.",
+                            "TRANSLATORS: Change this with your language and name ;)"));
 
     if (this->isHidden()) // FIXME: ugly workaround to avoid closing the program
     {                     // after closing About dialog, if mainWindow hidden
