@@ -106,6 +106,7 @@ Post::Post(PumpController *pumpController,
     postAuthorName->setToolTip(authorTooltipInfo);
 
     leftColumnLayout->addWidget(postAuthorName);
+    leftColumnLayout->addSpacing(4);
 
 
     QFont detailsFont;
@@ -118,47 +119,24 @@ Post::Post(PumpController *pumpController,
     QString exactPostTime = Timestamp::localTimeDate(createdAt);
     createdAt = Timestamp::fuzzyTime(createdAt);
 
-    postCreatedAt = new QLabel(createdAt + "\n");
-    postCreatedAt->setToolTip(exactPostTime + " " + tr("using") + " " + postData.value("generator"));
+    postCreatedAt = new QLabel(createdAt);
+    postCreatedAt->setToolTip(tr("Posted on %1, using %2","1=Date, 2=Program used")
+                              .arg(exactPostTime).arg(postData.value("generator")));
     postCreatedAt->setTextFormat(Qt::PlainText);
     postCreatedAt->setWordWrap(true);
     postCreatedAt->setAlignment(Qt::AlignLeft | Qt::AlignTop);
     postCreatedAt->setFont(detailsFont);
     leftColumnLayout->addWidget(postCreatedAt);
+    leftColumnLayout->addSpacing(4);
 
+    openInBrowserLabel = new QLabel("<br><a href=\"" + postData.value("url") + "\">Open &#9658;</a>");
+    openInBrowserLabel->setToolTip(tr("Open this post in your web browser"));
+    openInBrowserLabel->setOpenExternalLinks(true);
+    openInBrowserLabel->setFont(detailsFont);
+    leftColumnLayout->addWidget(openInBrowserLabel);
 
-    // Like, comment, share buttons
-    likeButton = new QPushButton(QIcon::fromTheme("emblem-favorite"), tr("Like"));
-    likeButton->setToolTip(tr("Like this post"));
-    likeButton->setCheckable(true);
-    likeButton->setFlat(true);
-    connect(likeButton, SIGNAL(clicked()),
-            this, SLOT(likePost()));
+    leftColumnLayout->addSpacing(12);
 
-    commentButton = new QPushButton(QIcon::fromTheme("mail-reply-sender"), tr("Comment"));
-    commentButton->setToolTip(tr("Comment on this post"));
-    commentButton->setFlat(true);
-    connect(commentButton, SIGNAL(clicked()),
-            this, SLOT(commentOnPost()));
-
-    shareButton = new QPushButton(QIcon::fromTheme("mail-forward"), tr("Share"));
-    shareButton->setToolTip(tr("Share this post"));
-    shareButton->setFlat(true);
-    connect(shareButton, SIGNAL(clicked()),
-            this, SLOT(sharePost()));
-
-    /* // Type-A button arrangement
-    buttonsLayout = new QHBoxLayout();
-    buttonsLayout->addWidget(likeButton);
-    buttonsLayout->addWidget(commentButton);
-    buttonsLayout->addWidget(shareButton);
-    buttonsLayout->setContentsMargins(0,0,0,0);
-    buttonsLayout->setAlignment(Qt::AlignLeft);
-    buttonsLayout->setMargin(0);
-    buttonsLayout->setSpacing(0);
-
-    leftColumnLayout->addLayout(buttonsLayout);
-    /**/
 
 
 
@@ -180,32 +158,64 @@ Post::Post(PumpController *pumpController,
     }
 
 
+    this->postLikesURL = postData.value("likesURL");
+    this->postCommentsURL = postData.value("commentsURL");
+
+
+
+    postLikesCount = new QLabel();
     QString likesCount = postData.value("likesCount");
     if (likesCount != "0")
     {
-        postLikesCount = new QLabel(QString::fromUtf8("\342\231\245 ") // heart symbol
+        if (likesCount == "1")
+        {
+            postLikesCount->setText(QString::fromUtf8("\342\231\245 ") // heart symbol
+                                  + tr("1 like"));
+        }
+        else
+        {
+            postLikesCount->setText(QString::fromUtf8("\342\231\245 ") // heart symbol
                                   + tr("%1 likes").arg(likesCount));
+        }
         postLikesCount->setWordWrap(true);
         postLikesCount->setAlignment(Qt::AlignLeft | Qt::AlignTop);
         postLikesCount->setFont(detailsFont);
         leftColumnLayout->addWidget(postLikesCount);
     }
 
+
+    postCommentsCount = new QLabel();
     QString commentsCount = postData.value("commentsCount");
     if (commentsCount != "0")
     {
-        postCommentsCount = new QLabel(tr("%1 comments").arg(commentsCount));
+        if (commentsCount == "1")
+        {
+            postCommentsCount->setText(tr("1 comment"));
+        }
+        else
+        {
+            postCommentsCount->setText(tr("%1 comments").arg(commentsCount));
+        }
         postCommentsCount->setWordWrap(true);
         postCommentsCount->setAlignment(Qt::AlignLeft | Qt::AlignTop);
         postCommentsCount->setFont(detailsFont);
         leftColumnLayout->addWidget(postCommentsCount);
     }
 
+    postResharesCount = new QLabel();
     QString resharesCount = postData.value("resharesCount");
     if (resharesCount != "0")
     {
-        postResharesCount = new QLabel(QString::fromUtf8("\342\231\272 ") // recycle symbol
-                                     + tr("%1 shares").arg(resharesCount));
+        if (resharesCount == "1")
+        {
+            postResharesCount->setText(QString::fromUtf8("\342\231\272 ") // recycle symbol
+                                      + tr("Shared one time"));
+        }
+        else
+        {
+            postResharesCount->setText(QString::fromUtf8("\342\231\272 ") // recycle symbol
+                                      + tr("Shared %1 times").arg(resharesCount));
+        }
         postResharesCount->setWordWrap(true);
         postResharesCount->setAlignment(Qt::AlignLeft | Qt::AlignTop);
         postResharesCount->setFont(detailsFont);
@@ -224,10 +234,39 @@ Post::Post(PumpController *pumpController,
     ///////////////////////////////////// Post text
     postText = new QTextBrowser();
     postText->setAlignment(Qt::AlignLeft | Qt::AlignTop);
+    //postText->setFrameStyle(QFrame::StyledPanel | QFrame::Raised); // Raised style? :-m
+    postText->setSizePolicy(QSizePolicy::MinimumExpanding,
+                            QSizePolicy::MinimumExpanding);
 
     postText->setWordWrapMode(QTextOption::WrapAtWordBoundaryOrAnywhere);
-    postText->setOpenExternalLinks(true); // don't open HTTP links, open in browser
+    postText->setOpenLinks(false); // don't open links, manage in openClickedURL()
     postText->setReadOnly(true); // it's default with QTextBrowser, but still...
+    connect(postText, SIGNAL(anchorClicked(QUrl)),
+            this, SLOT(openClickedURL(QUrl)));
+    connect(postText, SIGNAL(highlighted(QUrl)),
+            this, SLOT(showHighlightedURL(QUrl)));
+
+
+    // Like, comment, share buttons
+    likeButton = new QPushButton(QIcon::fromTheme("emblem-favorite"), "");
+    likeButton->setCheckable(true);
+    this->fixLikeButton(postData.value("postIsLiked"));
+    likeButton->setFlat(true);
+    connect(likeButton, SIGNAL(clicked(bool)),
+            this, SLOT(likePost(bool)));
+
+    commentButton = new QPushButton(QIcon::fromTheme("mail-reply-sender"), tr("Comment"));
+    commentButton->setToolTip(tr("Comment on this post"));
+    commentButton->setFlat(true);
+    connect(commentButton, SIGNAL(clicked()),
+            this, SLOT(commentOnPost()));
+
+    shareButton = new QPushButton(QIcon::fromTheme("mail-forward"), tr("Share"));
+    shareButton->setToolTip(tr("Share this post"));
+    shareButton->setFlat(true);
+    connect(shareButton, SIGNAL(clicked()),
+            this, SLOT(sharePost()));
+
 
 
     // Add like, comment, share and, if post is our own, delete buttons
@@ -252,9 +291,6 @@ Post::Post(PumpController *pumpController,
         buttonsLayout->addWidget(deleteButton, 0, Qt::AlignRight);
     }
 
-    // Type-B button arrangement
-    // postText->setLayout(buttonsLayout);
-
 
 
     // Get URL of post image, if it's "image" type of post
@@ -270,12 +306,18 @@ Post::Post(PumpController *pumpController,
         }
         else
         {
-            qDebug() << "Image not cached, downloading";
+            qDebug() << "Image not cached, downloading" << postImage;
             pumpController->getImage(postImage);
         }
 
-        postTitle = "<h2>" + postData.value("title") + "</h2><br>";
-        postImage = "<img src=\"" + MiscHelpers::getCachedImageFilename(postImage) + "\" width=\"400\"></img><br><br>";
+        this->postImageTitle = postData.value("title");
+        // If title's not empty, add the header tags and line break,
+        // otherwhise don't add useless <br>
+        if (!postImageTitle.isEmpty())
+        {
+            postTitle = "<h3>" + postImageTitle + "</h3><br>";
+        }
+        postImage = "<a href=\"image:/" + MiscHelpers::getCachedImageFilename(postImage) + "\"><img src=\"" + MiscHelpers::getCachedImageFilename(postImage) + "\" width=\"320\"></img></a><br><br>";
     }
 
 
@@ -286,11 +328,15 @@ Post::Post(PumpController *pumpController,
                     + postData.value("text"));
 
 
-    int postLines = postText->document()->lineCount();
+    int postLines = postText->document()->lineCount() + 1;
     qDebug() << "Post lines:" << postLines;
 
-    int postMinimumHeight = postLines * 3 * postText->fontInfo().pixelSize();
-    if (postMinimumHeight > 400)  // Don't allow a post to be higher than 400 px
+    int postMinimumHeight = postLines * 2 * postText->fontInfo().pixelSize();
+    if (postType == "image")
+    {
+        postMinimumHeight += 200;
+    }
+    if (postMinimumHeight > 400)  // Don't allow a post to have a minimum height > 400 px
     {
         postMinimumHeight = 400;  // Scrollbars will appear
         qDebug() << "Post would require more space: scrollbars might appear";
@@ -309,24 +355,20 @@ Post::Post(PumpController *pumpController,
 
 
     /////////////////////////////////////////////////////// Comments block
-    this->commenter = new Commenter();
+    this->commenter = new Commenter(this->pController);
     connect(commenter, SIGNAL(commentSent(QString)),
             this, SLOT(sendComment(QString)));
+    connect(commenter, SIGNAL(allCommentsRequested()),
+            this, SLOT(getAllComments()));
 
 
     rightColumnLayout->addWidget(postText,  7);
     rightColumnLayout->addLayout(buttonsLayout);
     rightColumnLayout->addWidget(commenter, 1);
 
-    QString commentsString;
-    foreach (QVariant commentMap, commentsVariantList)
-    {
-        commentsString = "<" + commentMap.toMap().value("author").toMap().value("displayName").toString() + "> "
-                + commentMap.toMap().value("content").toString() + "\n"
-                + commentsString;
-    }
 
-    this->commenter->setCommments(commentsString);
+    // Set the initial comments (4 most recent)
+    this->commenter->setComments(commentsVariantList);
 
 
 
@@ -355,6 +397,84 @@ Post::~Post()
 }
 
 
+
+/*
+ * Return the likes/favorites URL for this post
+ *
+ */
+QString Post::likesURL()
+{
+    return this->postLikesURL;
+}
+
+
+/*
+ * Update the tooltip in "%NUMBER likes" with the names
+ * of the people who liked the post
+ *
+ */
+void Post::setLikes(QVariantList likesList)
+{
+    if (likesList.size() > 0)
+    {
+        QString likesString;
+        foreach (QVariant likesMap, likesList)
+        {
+            likesString = likesMap.toMap().value("displayName").toString() + ", "
+                    + likesString;
+        }
+
+        // Remove last comma and add "like this"
+        likesString.remove(-2, 2); // Last 2 characters
+        likesString.append(" like this");
+
+        this->postLikesCount->setToolTip(likesString);
+    }
+}
+
+
+/*
+ * Return the comments URL for this post
+ *
+ */
+QString Post::commentsURL()
+{
+    return this->postCommentsURL;
+}
+
+
+/*
+ * Ask the Commenter to set new comments
+ *
+ */
+void Post::setComments(QVariantList commentsList)
+{
+    this->commenter->setComments(commentsList);
+}
+
+
+/*
+ * Return the shares URL for this post,
+ * list of people who reshared it
+ *
+ */
+QString Post::sharesURL()
+{
+    return this->postSharesURL;
+}
+
+/*
+ * Update the tooltip for "%NUMBER shares" with names
+ *
+ */
+void Post::setShares(QVariantList sharesList)
+{
+
+}
+
+
+
+
 void Post::resizeEvent(QResizeEvent *event)
 {
     //postText->adjustSize();
@@ -369,7 +489,9 @@ void Post::resizeEvent(QResizeEvent *event)
 
 
 
-//////////////////////////////// SLOTS ///////////////////////////////////
+////////////////////////////////////////////////////////////////////////////
+////////////////////////////////// SLOTS ///////////////////////////////////
+////////////////////////////////////////////////////////////////////////////
 
 
 void Post::showNsfwPost()
@@ -385,11 +507,33 @@ void Post::showNsfwPost()
  * Like (favorite) a post
  *
  */
-void Post::likePost()
+void Post::likePost(bool like)
 {
-    qDebug() << "Liking this post";
+    qDebug() << "Post::likePost()" << (like ? "like" : "unlike");
 
-    this->pController->likePost(this->postID, this->postType);
+    this->pController->likePost(this->postID, this->postType, like);
+
+    this->fixLikeButton(like ? "true" : "false");
+}
+
+/*
+ * Set the right labels and tooltips to the like button, depending on its state
+ *
+ */
+void Post::fixLikeButton(QString state)
+{
+    if (state == "true")
+    {
+        likeButton->setToolTip(tr("You like this"));
+        likeButton->setText(tr("Unlike"));
+        likeButton->setChecked(true);
+    }
+    else
+    {
+        likeButton->setToolTip(tr("Like this post"));
+        likeButton->setText(tr("Like"));
+        likeButton->setChecked(false);
+    }
 }
 
 
@@ -417,6 +561,15 @@ void Post::sendComment(QString comment)
 }
 
 
+void Post::getAllComments()
+{
+    this->pController->getPostComments(this->postCommentsURL);
+
+
+    this->pController->getPostLikes(this->postLikesURL); // tmp
+}
+
+
 /*
  * Re-share a post
  *
@@ -454,9 +607,43 @@ void Post::deletePost()
     {
         qDebug() << "Deleting post";
         this->pController->deletePost(this->postID, this->postType);
+
+        this->setDisabled(true); // disable... maybe hide?
     }
     else
     {
         qDebug() << "Confirmation cancelled, not deleting the post";
     }
 }
+
+
+
+void Post::openClickedURL(QUrl url)
+{
+    qDebug() << "Anchor URL clicked:" << url.toString();
+
+    if (url.scheme() == "image") // Use our own viewer, or maybe a configured external viewer
+    {
+        qDebug() << "Opening this image in our own viewer...";
+        ImageViewer *viewer = new ImageViewer(url.toString(), this->postImageTitle);
+        viewer->show();
+    }
+    else
+    {
+        qDebug() << "Opening this link in browser";
+        QDesktopServices::openUrl(url);
+    }
+
+
+}
+
+
+
+void Post::showHighlightedURL(QUrl url)
+{
+    QString urlString = url.toString();
+    if (!urlString.isEmpty())
+    {
+        qDebug() << "Highlighted url:" << urlString;
+    }
+}
