@@ -45,7 +45,7 @@
 #include "mischelpers.h"
 #include "pumpcontroller.h"
 #include "commenter.h"
-
+#include "imageviewer.h"
 
 class Post : public QFrame
 {
@@ -58,17 +58,29 @@ public:
          QWidget *parent = 0);
     ~Post();
 
+    QString likesURL();
+    void setLikes(QVariantList likesList);
+    QString commentsURL();
+    void setComments(QVariantList commentsList);
+    QString sharesURL();
+    void setShares(QVariantList sharesList);
+
 signals:
 
 public slots:
     void showNsfwPost();
 
-    void likePost();
+    void likePost(bool like);
+    void fixLikeButton(QString state);
     void commentOnPost();
     void sendComment(QString comment);
+    void getAllComments();
     void sharePost();
     void deletePost();
 
+    void openClickedURL(QUrl url);
+    void showHighlightedURL(QUrl url);
+
 protected:
     virtual void resizeEvent(QResizeEvent *event);
 
@@ -85,23 +97,31 @@ private:
     QLabel *postAuthorAvatar;
     QLabel *postAuthorName;
     QLabel *postCreatedAt;
+    QLabel *openInBrowserLabel;
     QLabel *postTypeLabel;
     QLabel *postRootAuthor;
     QLabel *postLikesCount;
     QLabel *postCommentsCount;
     QLabel *postResharesCount;
 
+
+    QTextBrowser *postText;
+
     QHBoxLayout *buttonsLayout;
     QPushButton *likeButton;
     QPushButton *commentButton;
     QPushButton *shareButton;
     QPushButton *deleteButton;
 
-    QTextBrowser *postText;
+
+    QString postImageTitle;
 
     QPushButton *nsfwCoveringButton;
 
     QStringList imageList;
+    QString postLikesURL;
+    QString postCommentsURL;
+    QString postSharesURL;
 
 
     PumpController *pController;
