@@ -22,7 +22,7 @@
 
 PumpController::PumpController(QObject *parent) :  QObject(parent)
 {
-    this->userAgentString = "Dianara/0.5";
+    this->userAgentString = "Dianara/0.6";
 
     this->postsPerPage = 20;
 
@@ -61,6 +61,7 @@ PumpController::PumpController(QObject *parent) :  QObject(parent)
     connect(&nam, SIGNAL(sslErrors(QNetworkReply*,QList<QSslError>)),
             this, SLOT(sslErrorsHandler(QNetworkReply*,QList<QSslError>)));
 
+
     this->initialDataStep = 0;
 
     initialDataTimer = new QTimer(this);
@@ -136,7 +137,8 @@ void PumpController::setUserCredentials(QString userID)
 
     // This will call getContactList() and getTimeLine(), etc.
     this->initialDataStep = 0;
-    this->initialDataTimer->start(100);  // start immediately
+    this->initialDataTimer->start(2000);  // start 2 seconds after setting the ID
+                                          // (mainly on program startup)
 }
 
 
@@ -146,6 +148,11 @@ QString PumpController::currentUserID()
     return this->userID;
 }
 
+QString PumpController::currentFollowersURL()
+{
+    return this->userFollowersURL;
+}
+
 
 
 
@@ -173,8 +180,12 @@ void PumpController::getUserProfile(QString userID)
 
 void PumpController::getAvatar(QString avatarURL)
 {
-    qDebug() << "Getting avatar";
+    if (avatarURL.isEmpty())
+    {
+        return;
+    }
 
+    qDebug() << "Getting avatar";
 
     QNetworkRequest avatarRequest(QUrl((const QString)avatarURL));
     avatarRequest.setRawHeader("User-Agent", userAgentString);
@@ -188,8 +199,10 @@ void PumpController::getAvatar(QString avatarURL)
 
 void PumpController::getImage(QString imageURL)
 {
-    // FIXME: now we get BadRequest on public images on other hosts
-    // Probably need to use "proxyURL" image
+    if (imageURL.isEmpty())
+    {
+        return;
+    }
 
     QNetworkRequest imageRequest = this->prepareRequest(imageURL, QOAuth::GET, ImageRequest);
 
@@ -201,22 +214,32 @@ void PumpController::getImage(QString imageURL)
 
 
 /*
- * GET https://pumpserver.example/api/......
+ * GET https://pumpserver.example/api/user/username/following or /followers
  *
  */
-void PumpController::getContactList()
+void PumpController::getContactList(QString listType)
 {
-    emit currentJobChanged(tr("Getting contact list..."));
-    qDebug() << "Getting contact list";
+    qDebug() << "Getting contact list, type" << listType;
 
-    QString url = "https://" + this->serverURL + "/api/user/" +this->userName + "/following";
-                                                                                // also /followers?
+    QString url = "https://" + this->serverURL + "/api/user/" +this->userName + "/" + listType;
 
     QOAuth::ParamMap paramMap;
     paramMap.insert("count", "100");  // TMP/FIXME get 100 contacts
 
-    QNetworkRequest contactListRequest = this->prepareRequest(url, QOAuth::GET,
-                                                              ContactListRequest, paramMap);
+    QNetworkRequest contactListRequest;
+    if (listType == "following")
+    {
+        emit currentJobChanged(tr("Getting followed list..."));
+        contactListRequest = this->prepareRequest(url, QOAuth::GET,
+                                                  FollowingListRequest, paramMap);
+    }
+    else
+    {
+        emit currentJobChanged(tr("Getting followers list..."));
+        contactListRequest = this->prepareRequest(url, QOAuth::GET,
+                                                  FollowersListRequest, paramMap);
+    }
+
     nam.get(contactListRequest);
 }
 
@@ -230,6 +253,7 @@ void PumpController::getContactList()
 void PumpController::getTimeline(int timelineOffset)
 {
     emit currentJobChanged(tr("Getting timeline..."));
+    emit timeLineOffsetChanged(timelineOffset);
 
     QString url = "https://" + this->serverURL + "/api/user/" + this->userName + "/inbox/major";
 
@@ -254,23 +278,58 @@ void PumpController::getTimeline(int timelineOffset)
 
 
 /*
- * Get one specific post
- *
- * GET https://pumpserver.example/api/posts/.....
+ * Get list of people who liked a specific post
  *
  */
-void PumpController::getPost(int id)
+void PumpController::getPostLikes(QString postLikesURL)
 {
-    qDebug() << "Getting post" << id;
+    qDebug() << "Getting likes for post" << postLikesURL;
+
+    emit currentJobChanged(tr("Getting likes..."));
 
 
-    QNetworkRequest postRequest(QUrl("https://" + this->serverURL
-                                     + "/api/posts/" + QString("%1").arg(id) ));
-    postRequest.setRawHeader("User-Agent", userAgentString);
-    postRequest.setAttribute(QNetworkRequest::User,
-                             QVariant(PostRequest));
+    QOAuth::ParamMap paramMap;
+    paramMap.insert("count", "50"); // TMP, up to 50 likes
+
+    QNetworkRequest likesRequest = this->prepareRequest(postLikesURL, QOAuth::GET,
+                                                        PostLikesRequest, paramMap);
+
+    nam.get(likesRequest);
+}
+
+
+
+/*
+ * Get comments for one specific post
+ *
+ * GET https://pumpserver.example/api/note/#id#/replies
+ * or proxyed URL. URL is given by the post itself anyway
+ *
+ */
+void PumpController::getPostComments(QString postCommentsURL)
+{
+    qDebug() << "Getting comments for post" << postCommentsURL;
+
+    emit currentJobChanged(tr("Getting comments..."));
+
+
+    QOAuth::ParamMap paramMap;
+    paramMap.insert("count", "50"); // TMP, up to 50 comments
+
+    QNetworkRequest commentsRequest = this->prepareRequest(postCommentsURL, QOAuth::GET,
+                                                           PostCommentsRequest, paramMap);
+
+    nam.get(commentsRequest);
+}
+
+
+/*
+ * Get list of people who shared a specific post
+ *
+ */
+void PumpController::getPostShares(QString postSharesURL)
+{
 
-    nam.get(postRequest);
 }
 
 
@@ -280,7 +339,8 @@ void PumpController::getPost(int id)
  *
  */
 QNetworkRequest PumpController::prepareRequest(QString url, QOAuth::HttpMethod method,
-                                               int requestType, QOAuth::ParamMap paramMap)
+                                               int requestType, QOAuth::ParamMap paramMap,
+                                               QString contentTypeString)
 {
     QByteArray authorizationHeader = qoauth->createParametersString(url,
                                                                  method,
@@ -298,7 +358,7 @@ QNetworkRequest PumpController::prepareRequest(QString url, QOAuth::HttpMethod m
     }
     request.setUrl(QUrl(url));
     request.setRawHeader("Authorization", authorizationHeader);
-    request.setHeader(QNetworkRequest::ContentTypeHeader, "application/json");
+    request.setHeader(QNetworkRequest::ContentTypeHeader, contentTypeString);
     request.setRawHeader("User-Agent", userAgentString);
 
 
@@ -309,6 +369,35 @@ QNetworkRequest PumpController::prepareRequest(QString url, QOAuth::HttpMethod m
 
 
 
+/*
+ * Upload a file to the /uploads feed for the user
+ *
+ * Used to upload pictures, but might have more uses in the future
+ *
+ */
+void PumpController::uploadFile(QString filename, QString contentType)
+{
+    qDebug() << "PumpController::uploadFile()";
+
+    QString url = "https://" + this->serverURL + "/api/user/" + this->userName + "/uploads";
+
+    QNetworkRequest postRequest = this->prepareRequest(url, QOAuth::POST,
+                                                       UploadFileRequest,
+                                                       QOAuth::ParamMap(),
+                                                       contentType);
+
+    QFile file(filename);
+    file.open(QIODevice::ReadOnly);
+
+    QByteArray data = file.readAll();
+    file.close();
+
+
+    nam.post(postRequest, data);
+}
+
+
+
 /***************************************************************************/
 /***************************************************************************/
 /***************************************************************************/
@@ -366,6 +455,9 @@ void PumpController::requestFinished(QNetworkReply *reply)
         //qDebug() << reply->attribute(QNetworkRequest::HttpReasonPhraseAttribute);
         return;
 
+    case 0:
+        emit currentJobChanged(tr("Error connecting to %1").arg(reply->url().host()) + ": " + reply->errorString());
+        return;
 
     case 200:
         qDebug() << "HTTP 200: OK!";
@@ -400,16 +492,15 @@ void PumpController::requestFinished(QNetworkReply *reply)
             emit currentJobChanged(tr("Following successfully."));
 
             // Re-request the contact list, now with a new contact (not very optimized...)
-            this->getContactList();
+            this->getContactList("following");
             break;
 
         case UnfollowContactRequest:
             emit currentJobChanged(tr("Stopped following successfully."));
 
             // Re-request the contact list, now with one contact less (not very optimized...)
-            this->getContactList();
+            this->getContactList("following");
             break;
-
         }
     }
 
@@ -471,6 +562,9 @@ void PumpController::requestFinished(QNetworkReply *reply)
                 QString profImageUrl = jsonData["profile"].toMap()["image"].toMap()["url"].toString();
 
                 emit profileReceived(profDisplayName, profImageUrl);
+
+                // Store also the user's followers URL, for posting to Followers
+                this->userFollowersURL = jsonData["profile"].toMap().value("followers").toMap().value("url").toString();
             }
         }
 
@@ -485,7 +579,6 @@ void PumpController::requestFinished(QNetworkReply *reply)
 
         jsonData = jsonParser.parse(packetData, &jsonParsedOK).toMap();
         qDebug() << "JSON data size (items):" << jsonData.size();
-        qDebug() << jsonData.keys();
 
         if (jsonParsedOK && jsonData.size() > 0)
         {
@@ -508,18 +601,102 @@ void PumpController::requestFinished(QNetworkReply *reply)
         break;
 
 
+    ///////////////////////////////////// If the likes for a post were requested
+    case PostLikesRequest:
+        qDebug() << "Likes for a post were requested" << reply->url().toString();
 
-    ///////////////////////////////////////// If a single post was requested, by ID
-    case PostRequest:
-        qDebug() << "A single post was requested";
+        jsonData = jsonParser.parse(packetData, &jsonParsedOK).toMap();
+        qDebug() << "JSON data size (items):" << jsonData.size();
+
+        if (jsonParsedOK && jsonData.size() > 0)
+        {
+            qDebug() << "JSON parsed OK";
+            emit currentJobChanged(tr("Likes received."));
+
+            jsonDataList = jsonData["items"].toList();
+            qDebug() << "Number of items in comments list:" << jsonDataList.size();
+
+            emit likesReceived(jsonDataList, reply->url().toString());
+        }
+        else
+        {
+            qDebug() << "Error parsing received comment JSON data!";
+            qDebug() << "Raw data:" << packetData;
+        }
+        break;
+
+
+
+    ///////////////////////////////////// If the comments for a post were requested
+    case PostCommentsRequest:
+        qDebug() << "Comments for a post were requested" << reply->url().toString();
+
+        jsonData = jsonParser.parse(packetData, &jsonParsedOK).toMap();
+        qDebug() << "JSON data size (items):" << jsonData.size();
+
+        if (jsonParsedOK && jsonData.size() > 0)
+        {
+            qDebug() << "JSON parsed OK";
+            emit currentJobChanged(tr("Comments received."));
+
+            jsonDataList = jsonData["items"].toList();
+            qDebug() << "Number of items in comments list:" << jsonDataList.size();
+
+            emit commentsReceived(jsonDataList, reply->url().toString());
+        }
+        else
+        {
+            qDebug() << "Error parsing received comment JSON data!";
+            qDebug() << "Raw data:" << packetData;
+        }
+        break;
+
+
+
+    case PostSharesRequest:
+        break;
+
+
+
+    //////////////////////////////////////// If uploading a file was requested
+    case UploadFileRequest:
+        qDebug() << "Uploading a file was requested";
+
+        jsonData = jsonParser.parse(packetData, &jsonParsedOK).toMap();
+        qDebug() << "JSON data size (items):" << jsonData.size();
+        qDebug() << jsonData.keys();
+
+        if (jsonParsedOK && jsonData.size() > 0)
+        {
+            qDebug() << "JSON parsed OK";
+            emit currentJobChanged(tr("File uploaded succesfully. Posting message..."));
+
+            QString uploadedFileID = jsonData["id"].toString();
+            qDebug() << "Uploaded file ID:" << uploadedFileID;
+
+
+            if (jsonData["objectType"].toString() == "image")
+            {
+                this->postImageStepTwo(uploadedFileID);
+            }
+        }
+        else
+        {
+            qDebug() << "Error parsing received JSON data!";
+            qDebug() << "Raw data:" << packetData; // JSON directly
+        }
 
         break;
 
 
 
 
-    case ContactListRequest:
-        qDebug() << "The contact list was requested";
+
+
+    case FollowingListRequest:
+        // just go to next
+    case FollowersListRequest:
+        qDebug() << "A contact list was requested";
 
         jsonData = jsonParser.parse(packetData, &jsonParsedOK).toMap();
         qDebug() << "JSON data size (items):" << jsonData.size();
@@ -532,8 +709,17 @@ void PumpController::requestFinished(QNetworkReply *reply)
             if (contactsVariant.type() == QVariant::List)
             {
                 qDebug() << "Parsed a List, listing contacts...";
-                emit currentJobChanged(tr("Contact list received."));
-                emit contactListReceived(contactsVariant.toList());
+
+                if (requestType == FollowingListRequest)
+                {
+                    emit currentJobChanged(tr("Followed list received."));
+                    emit contactListReceived("following", contactsVariant.toList());
+                }
+                else // == FollowersListRequest
+                {
+                    emit currentJobChanged(tr("Followers list received."));
+                    emit contactListReceived("followers", contactsVariant.toList());
+                }
             }
             else
             {
@@ -555,7 +741,6 @@ void PumpController::requestFinished(QNetworkReply *reply)
         qDebug() << "Received AVATAR data, from " << reply->url();
         // FIXME: take care of possible redirections
 
-        //this->avatarData.append(packetData);
         if (reply->isFinished())
         {
             qDebug() << "Avatar received 100%";
@@ -570,7 +755,7 @@ void PumpController::requestFinished(QNetworkReply *reply)
 
     case ImageRequest:
         qDebug() << "Received IMAGE data, from " << reply->url();
-        //this->imageData.append(packetData);
+
         if (reply->isFinished())
         {
             qDebug() << "Image received 100%";
@@ -740,19 +925,24 @@ void PumpController::getInitialData()
 {
     qDebug() << "PumpController::getInitialData() step" << initialDataStep;
 
-    initialDataTimer->setInterval(2000);  // Every 2 sec
+    initialDataTimer->setInterval(3000);  // Every 3 sec
 
 
     switch (this->initialDataStep)
     {
     case 0:
-        this->getContactList();
+        this->getTimeline(0);
         break;
 
     case 1:
-        this->getTimeline();
+        this->getContactList("following");
         break;
 
+    case 2:
+        this->getContactList("followers");
+        break;
+
+
 
     default:
         emit currentJobChanged(tr("Ready.")); // FIXME
@@ -770,20 +960,42 @@ void PumpController::getInitialData()
 
 
 /*
- * Send a post ("note") to the server
+ * Send a NOTE to the server
  *
  */
-void PumpController::post(QString postText)
+void PumpController::postNote(QMap<QString, QString> audienceMap,
+                              QString postText)
 {
-    qDebug() << "PumpController::post()";
-
-
+    qDebug() << "PumpController::postNote()";
 
     QString url = "https://" + this->serverURL + "/api/user/" + this->userName + "/feed";
 
     QNetworkRequest postRequest = this->prepareRequest(url, QOAuth::POST, PublishPostRequest);
 
 
+    qDebug() << "Should be posting to:" << audienceMap;
+
+
+    QVariantList jsonVariantTo;
+    QVariantMap jsonVariantAudienceItem;
+    while (!audienceMap.isEmpty())
+    {
+        if (audienceMap.keys().contains("collection"))
+        {
+            QString collectionID = audienceMap.take("collection");
+            jsonVariantAudienceItem.insert("objectType", "collection");
+            jsonVariantAudienceItem.insert("id", collectionID);
+        }
+        else if (audienceMap.keys().contains("person"))
+        {
+            QString personID = audienceMap.take("person");
+            jsonVariantAudienceItem.insert("objectType", "person");
+            jsonVariantAudienceItem.insert("id", personID);
+        }
+        jsonVariantTo.append(jsonVariantAudienceItem);
+    }
+
+
     QVariantMap jsonVariantObject;
     jsonVariantObject.insert("objectType", "note");
     jsonVariantObject.insert("content", postText);
@@ -791,6 +1003,68 @@ void PumpController::post(QString postText)
     QVariantMap jsonVariant;
     jsonVariant.insert("verb", "post");
     jsonVariant.insert("object", jsonVariantObject);
+    jsonVariant.insert("to", jsonVariantTo);
+
+
+
+    QJson::Serializer serializer;
+    bool ok;
+    QByteArray data = serializer.serialize(jsonVariant, &ok);
+
+
+    qDebug() << "About to POST:" << data;
+
+    nam.post(postRequest, data);
+}
+
+
+/*
+ * Send an IMAGE to the server
+ *
+ * First, upload the file.
+ * Then we get it's ID in a signal, and create the post itself
+ *
+ */
+void PumpController::postImage(QMap<QString, QString> audienceMap,
+                               QString postText, QString imageTitle,
+                               QString imageFilename, QString contentType)
+{
+    qDebug() << "PumpController::postImage()";
+    qDebug() << "Uploading" << imageFilename << "with title:" << imageTitle;
+
+    // Store postText and imageTitle, then upload
+    this->imageTitle = imageTitle;
+    this->imageDescription = postText;
+
+
+    this->uploadFile(imageFilename, contentType);
+}
+
+
+/*
+ * Post Image, step 2: after getting the ID in the file upload request,
+ * create the post itself
+ *
+ */
+void PumpController::postImageStepTwo(QString id)
+{
+    qDebug() << "PumpController::postImageStepTwo() image ID:" << id;
+
+    QString url = "https://" + this->serverURL + "/api/user/" + this->userName + "/feed";
+
+    QNetworkRequest postRequest = this->prepareRequest(url, QOAuth::POST, PublishPostRequest);
+
+
+    QVariantMap jsonVariantObject;
+    jsonVariantObject.insert("objectType", "image");
+    jsonVariantObject.insert("id", id);
+    jsonVariantObject.insert("displayName", this->imageTitle);   // not 'title'
+    jsonVariantObject.insert("content", this->imageDescription); // not 'description' or 'summary'
+
+    QVariantMap jsonVariant;
+    jsonVariant.insert("verb", "post");
+    jsonVariant.insert("object", jsonVariantObject);
+
 
     QJson::Serializer serializer;
     bool ok;
@@ -808,7 +1082,7 @@ void PumpController::post(QString postText)
  * Like (favorite) a post, by its URL
  *
  */
-void PumpController::likePost(QString postID, QString postType)
+void PumpController::likePost(QString postID, QString postType, bool like)
 {
     qDebug() << "PumpController::likePost() liking post" << postID;
 
@@ -822,7 +1096,7 @@ void PumpController::likePost(QString postID, QString postType)
     jsonVariantObject.insert("id", postID);
 
     QVariantMap jsonVariant;
-    jsonVariant.insert("verb", "favorite");
+    jsonVariant.insert("verb", like ? "favorite":"unfavorite"); // like or unlike
     jsonVariant.insert("object", jsonVariantObject);
 
     QJson::Serializer serializer;
