@@ -33,6 +33,7 @@
 #include <QNetworkAccessManager>
 #include <QSslError> // TMP
 #include <QTimer>
+#include <QFile>
 
 #include <QSettings>
 #include <QDesktopServices>
@@ -63,18 +64,26 @@ public:
     void setNewUserID(QString userID);
     void setUserCredentials(QString userID);
     QString currentUserID();
+    QString currentFollowersURL();
 
     void getUserProfile(QString userID);
     void getAvatar(QString avatarURL);
     void getImage(QString imageURL);
-    void getContactList();
-    void getTimeline(int timelineOffset = 0);
-    void getPost(int id);
+    void getContactList(QString listType);
+    void getTimeline(int timelineOffset);
+
+    void getPostLikes(QString postLikesURL);
+    void getPostComments(QString postCommentsURL);
+    void getPostShares(QString postSharesURL);
+
 
     QNetworkRequest prepareRequest(QString url,
                                    QOAuth::HttpMethod method,
                                    int requestType,
-                                   QOAuth::ParamMap paramMap = QOAuth::ParamMap());
+                                   QOAuth::ParamMap paramMap = QOAuth::ParamMap(),
+                                   QString contentTypeString="application/json");
+
+    void uploadFile(QString filename, QString contentType);
 
     enum requestTypes
     {
@@ -84,9 +93,14 @@ public:
         TokenRequest,
 
         UserProfileRequest,
-        ContactListRequest,
+        FollowingListRequest,
+        FollowersListRequest,
+
         TimelineRequest,
-        PostRequest,
+        PostLikesRequest,
+        PostCommentsRequest,
+        PostSharesRequest,
+
         AvatarRequest,
         ImageRequest,
 
@@ -97,19 +111,25 @@ public:
         DeletePostRequest,
 
         FollowContactRequest,
-        UnfollowContactRequest
+        UnfollowContactRequest,
+
+        UploadFileRequest
     };
 
 
 
+
 signals:
     void authorizationStatusChanged(bool authorized);
 
     void profileReceived(QString fullName, QString avatarURL);
-    void contactListReceived(QVariantList contactList);
+    void contactListReceived(QString listType, QVariantList contactList);
     void timeLineReceived(QVariantList postList, int postsPerPage,
                           QString previousLink, QString nextLink);
-    void postReceived(QVariantMap post);
+    void likesReceived(QVariantList likesList, QString originatingPostURL);
+    void commentsReceived(QVariantList commentsList, QString originatingPostURL);
+
+    void timeLineOffsetChanged(int offset);
     void avatarPictureReceived(QByteArray pictureData, QUrl pictureURL);
     void imageReceived(QByteArray pictureData, QUrl pictureURL);
 
@@ -117,6 +137,7 @@ signals:
     void currentJobChanged(QString message);
 
 
+
 public slots:
     void requestFinished(QNetworkReply *reply);
     void sslErrorsHandler(QNetworkReply *reply, QList<QSslError> errorList); // Tests
@@ -126,8 +147,14 @@ public slots:
 
     void getInitialData();
 
-    void post(QString postText); // FIXME: more params
-    void likePost(QString postID, QString postType);
+    void postNote(QMap<QString,QString> audienceMap,
+                  QString postText);
+    void postImage(QMap<QString,QString> audienceMap,
+                   QString postText, QString imageTitle,
+                   QString imageFilename, QString contentType);
+    void postImageStepTwo(QString id);
+
+    void likePost(QString postID, QString postType, bool like);
     void addComment(QString comment, QString postID, QString postType);
     void sharePost(QString postID, QString postType);
     void deletePost(QString postID, QString postType);
@@ -147,6 +174,8 @@ private:
     QString userName;
     QString serverURL;
 
+    QString userFollowersURL;
+
     // QOAuth-related
     QOAuth::Interface *qoauth;
 
@@ -159,12 +188,14 @@ private:
     QByteArray tokenSecret;
 
 
-
     QTimer *initialDataTimer;
     int initialDataStep;
 
 
     int postsPerPage;
+
+    QString imageTitle;
+    QString imageDescription;
 };
 
 #endif // PUMPCONTROLLER_H
