@@ -23,6 +23,8 @@
 TimeLine::TimeLine(PumpController *pumpController, QWidget *parent) :  QWidget(parent)
 {
     this->pController = pumpController;
+    connect(pController, SIGNAL(timeLineOffsetChanged(int)),
+            this, SLOT(syncTimelineOffset(int)));  // keep timeline offset coherent
 
     mainLayout = new QVBoxLayout();
     mainLayout->setAlignment(Qt::AlignTop);
@@ -35,7 +37,7 @@ TimeLine::TimeLine(PumpController *pumpController, QWidget *parent) :  QWidget(p
                                   "Upon startup, timeline should update automatically.<br><br>"
                                   "<a href=\"http://jancoding.wordpress.com/dianara\">Dianara's blog</a><br>"
                                   "<a href=\"http://dianara.nongnu.org\">Dianara's website</a><br><br>");
-    demoPostData.insert("createdAt", "1970-01-01T01:02:03Z");
+    demoPostData.insert("createdAt", "2000-01-01T00:01:02Z");
     demoPostData.insert("likesCount", "32");
     demoPostData.insert("commentsCount", "128");
     demoPostData.insert("resharesCount", "256");
@@ -100,8 +102,7 @@ void TimeLine::clearTimeLineContents()
     // Build list of widgets contained in the layout
     for (int counter = 0; counter < splitter->count(); ++counter)
     {
-        qDebug() << "Adding for deletion:" << splitter->widget(counter);
-
+        //qDebug() << "Adding for deletion:" << splitter->widget(counter);
         previousPostList.append(splitter->widget(counter));
     }
 
@@ -110,16 +111,16 @@ void TimeLine::clearTimeLineContents()
 
     foreach (QWidget *oldPost, previousPostList)
     {
-        //delete mainLayout->itemAt(counter)->widget();
-        //mainLayout->itemAt(counter)->widget()->deleteLater();
-
         qDebug() << "will deleteLater:" << oldPost;
         oldPost->deleteLater(); // delete should be safe too, but still...
     }
 
+    this->postsInTimeline.clear();
 
-    /* This is to avoid the splitter getting bigger and bigger everytime the user
+    /*
+     * This is to avoid the splitter getting bigger and bigger everytime the user
      * updates the timeline (F5, etc)
+     *
      */
     this->splitter->setMinimumHeight(0);
     this->splitter->resize(1,1);
@@ -127,7 +128,12 @@ void TimeLine::clearTimeLineContents()
 
 
 
+/*********************************************************/
+/*********************************************************/
 /************************ SLOTS **************************/
+/*********************************************************/
+/*********************************************************/
+
 
 
 void TimeLine::setTimeLineContents(QVariantList postList, int postsPerPage,
@@ -163,6 +169,7 @@ void TimeLine::setTimeLineContents(QVariantList postList, int postsPerPage,
 
 
             QString postID;
+            QString postURL;
             QString postType;
             QString postAuthor;
             QString postAuthorAvatar;
@@ -179,6 +186,8 @@ void TimeLine::setTimeLineContents(QVariantList postList, int postsPerPage,
             QString postLikesCount;
             QString postCommentsCount;
             QString postResharesCount;
+
+            QString postIsLiked;
             QString postIsShared;
 
 
@@ -208,10 +217,12 @@ void TimeLine::setTimeLineContents(QVariantList postList, int postsPerPage,
                 }
             }
 
+            postURL = singlePostMap.value("object").toMap().value("url").toString();
 
             postType = singlePostMap.value("object").toMap().value("objectType").toString();
+
+            postIsLiked = singlePostMap.value("object").toMap().value("liked").toString();
             postIsShared = singlePostMap.value("object").toMap().value("pump_io").toMap().value("shared").toString();
-            //qDebug() << "post type:" << postType << "post is shared:" << postIsShared;
 
             postAuthor = singlePostMap.value("actor").toMap().value("displayName").toString();
             postAuthorAvatar = singlePostMap.value("actor").toMap().value("image").toMap().value("url").toString();
@@ -234,14 +245,32 @@ void TimeLine::setTimeLineContents(QVariantList postList, int postsPerPage,
             {
                 postTitle = singlePostMap.value("object").toMap().value("displayName").toString();
 
-                // See if there's a proxy URL for the image first (for private images)
-                postImage = singlePostMap.value("object").toMap().value("image").toMap().value("pump_io").toMap().value("proxyURL").toString();
 
-                // If that's empty, use regular image->url field
+                // See if there's a proxy URL for the image first (for private images)
+                postImage = singlePostMap.value("object").toMap().value("fullImage").toMap().value("pump_io").toMap().value("proxyURL").toString();
+                qDebug() << "Trying Proxyed fullImage";
+
+                // if that's empty, try the "small" version
                 if (postImage.isEmpty())
                 {
+                    qDebug() << "Trying Proxyed thumbnail image";
+                    postImage = singlePostMap.value("object").toMap().value("image").toMap().value("pump_io").toMap().value("proxyURL").toString();
+                }
+
+                // If that's also empty, use regular fullImage->url field
+                if (postImage.isEmpty())
+                {
+                    qDebug() << "Trying direct fullImage";
+                    postImage = singlePostMap.value("object").toMap().value("fullImage").toMap().value("url").toString();
+                }
+
+                // And if that is ALSO empty, use regular image->url
+                if (postImage.isEmpty())
+                {
+                    qDebug() << "Trying direct thumbnail image";
                     postImage = singlePostMap.value("object").toMap().value("image").toMap().value("url").toString();
                 }
+                qDebug() << "postImage:" << postImage;
             }
 
 
@@ -252,12 +281,29 @@ void TimeLine::setTimeLineContents(QVariantList postList, int postsPerPage,
             postResharesCount = singlePostMap.value("object").toMap().value("shares").toMap().value("totalItems").toString();
 
             // get comments list here, pass to the Post()
-            QVariantList commentsList = singlePostMap.value("object").toMap().value("replies").toMap().value("items").toList();
+            QVariantList lastCommentsList = singlePostMap.value("object").toMap().value("replies").toMap().value("items").toList();
+
+
+            // Get URL for likes; first, proxyURL if it exists
+            QString postLikesURL = singlePostMap.value("object").toMap().value("likes").toMap().value("pump_io").toMap().value("proxyURL").toString();
+            // If still empty, get regular URL (that means the post is in the same server we are)
+            if (postLikesURL.isEmpty())
+            {
+                postLikesURL = singlePostMap.value("object").toMap().value("likes").toMap().value("url").toString();
+            }
+
+            // Get URL for comments; first, proxyURL if it exists
+            QString postCommentsURL = singlePostMap.value("object").toMap().value("replies").toMap().value("pump_io").toMap().value("proxyURL").toString();
+            if (postCommentsURL.isEmpty()) // If still empty, get regular URL
+            {
+                postCommentsURL = singlePostMap.value("object").toMap().value("replies").toMap().value("url").toString();
+            }
 
 
 
             QMap<QString,QString> postData;
             postData.insert("id",                 postID);
+            postData.insert("url",                postURL);
             postData.insert("postType",           postType);
             postData.insert("author",             postAuthor);
             postData.insert("authorAvatar",       postAuthorAvatar);
@@ -272,15 +318,25 @@ void TimeLine::setTimeLineContents(QVariantList postList, int postsPerPage,
             postData.insert("nsfw",               postIsNsfw);
             postData.insert("rootAuthor",         postRootAuthor);
             postData.insert("likesCount",         postLikesCount);
+            postData.insert("likesURL",           postLikesURL);
             postData.insert("commentsCount",      postCommentsCount);
+            postData.insert("commentsURL",        postCommentsURL);
             postData.insert("resharesCount",      postResharesCount);
+
+            postData.insert("postIsLiked",        postIsLiked);
             postData.insert("postIsShared",       postIsShared);
 
 
 
             if (postIsDeleted.isEmpty())  // if post was NOT deleted
             {
-                this->splitter->addWidget(new Post(pController, postData, commentsList, this));
+                Post *newPost = new Post(pController, postData, lastCommentsList, this);
+                this->postsInTimeline.append(newPost);
+
+                this->splitter->addWidget(newPost);
+
+                this->splitter->setMinimumHeight(this->splitter->height()
+                                                 + newPost->sizeHint().height());
             }
             else
             {
@@ -293,9 +349,6 @@ void TimeLine::setTimeLineContents(QVariantList postList, int postsPerPage,
             this->splitter->setStretchFactor(splitter->count()-1,
                                              splitter->widget(splitter->count()-1)->height()/200);
             */
-
-            // TMP FIXME, avoid unresizable posts (not enough height on splitter area)
-            this->splitter->setMinimumHeight(this->splitter->height() + 200); // was 400
         }
         else  // singlePost.type() is not a QVariant::Map
         {
@@ -318,13 +371,84 @@ void TimeLine::setTimeLineContents(QVariantList postList, int postsPerPage,
 
 
 
+/*
+ * Keep timeline offset in sync
+ *
+ */
+void TimeLine::syncTimelineOffset(int offset)
+{
+    this->timelineOffset = offset;
+}
+
+
+
+
+/*
+ * Add the full list of likes to a post
+ *
+ */
+void TimeLine::setLikesInPost(QVariantList likesList, QString originatingPostURL)
+{
+    qDebug() << "TimeLine::setLikesInPost()";
+
+    QString originatingPostCleanURL = originatingPostURL.split("?").at(0);
+    qDebug() << "Originating post URL:" << originatingPostCleanURL;
+
+
+    // Look for the originating Post() object
+    qDebug() << "Looking for the originating Post() object";
+    foreach (Post *post, postsInTimeline)
+    {
+        qDebug() << "Checking if" << post->commentsURL() << "==" << originatingPostCleanURL;
+
+        if (post->likesURL() == originatingPostCleanURL)
+        {
+            qDebug() << "Found originating Post; setting likes on it...";
+            post->setLikes(likesList);
+
+            break;
+        }
+    }
+}
+
+
+/*
+ * Add the full list of comments to a post
+ *
+ */
+void TimeLine::setCommentsInPost(QVariantList commentsList, QString originatingPostURL)
+{
+    qDebug() << "TimeLine::setCommentsInPost()";
+
+    QString originatingPostCleanURL = originatingPostURL.split("?").at(0);
+    qDebug() << "Originating post URL:" << originatingPostCleanURL;
+
+
+    // Look for the originating Post() object
+    qDebug() << "Looking for the originating Post() object";
+    foreach (Post *post, postsInTimeline)
+    {
+        qDebug() << "Checking if" << post->commentsURL() << "==" << originatingPostCleanURL;
+
+        if (post->commentsURL() == originatingPostCleanURL)
+        {
+            qDebug() << "Found originating Post; setting comments on it...";
+            post->setComments(commentsList);
+
+            break;
+        }
+    }
+}
+
+
+
+
 
 void TimeLine::goToFirstPage()
 {
     qDebug() << "TimeLine::goToFirstPage()";
-    this->pController->getTimeline();
-
-    this->timelineOffset = 0; // Keep timeline offset coherent
+    this->pController->getTimeline(0); // getTimeline will emit timelineOffsetChanged
+                                       // to keep it sync'd
 }
 
 
