@@ -57,6 +57,10 @@ signals:
 public slots:
     void setTimeLineContents(QVariantList postList, int postsPerPage,
                              QString previousLink, QString nextLink);
+    void syncTimelineOffset(int offset);
+
+    void setLikesInPost(QVariantList likesList, QString originatingPostURL);
+    void setCommentsInPost(QVariantList commentsList, QString originatingPostURL);
 
     void goToFirstPage();
     void goToPreviousPage();
@@ -80,6 +84,8 @@ private:
     int postsPerPage;
 
     QString previousNewestPostID;
+
+    QList<Post *> postsInTimeline;
 };
 
 #endif // TIMELINE_H
