@@ -57,16 +57,14 @@ QString Timestamp::localTimeDate(QString isoTime)
  */
 QString Timestamp::fuzzyTime(QString isoTime)
 {
-    //qDebug() << "::fuzzyTime - isoTime: " << isoTime;
     QDateTime dateTimeConverter = QDateTime::fromString(isoTime, Qt::ISODate);
-    //qDebug() << dateTimeConverter.toTime_t();
-    //qDebug() << QDateTime::currentDateTimeUtc().toTime_t();
 
     int timeDifference = QDateTime::currentDateTimeUtc().toTime_t()
                          - dateTimeConverter.toTime_t();
     //qDebug() << "time difference in seconds:" << timeDifference;
 
-    QString localTimeDateString = QString("About %1 ago");
+    QString localTimeDateString = QString("About ... ago");
+
 
     // At this point, timeDifference is in SECONDS
 
@@ -79,7 +77,14 @@ QString Timestamp::fuzzyTime(QString isoTime)
         timeDifference /= 60; // convert to minutes
         if (timeDifference < 60) // less than an hour
         {
-            localTimeDateString = tr("%1 minutes ago").arg(timeDifference);
+            if (timeDifference == 1)
+            {
+                localTimeDateString = tr("A minute ago");
+            }
+            else
+            {
+                localTimeDateString = tr("%1 minutes ago").arg(timeDifference);
+            }
         }
         else
         {
@@ -87,7 +92,14 @@ QString Timestamp::fuzzyTime(QString isoTime)
 
             if (timeDifference < 24) // less than a day
             {
-                localTimeDateString = tr("About %1 hours ago").arg(timeDifference);
+                if (timeDifference == 1)
+                {
+                    localTimeDateString = tr("An hour ago");
+                }
+                else
+                {
+                    localTimeDateString = tr("%1 hours ago").arg(timeDifference);
+                }
             }
             else
             {
@@ -95,7 +107,14 @@ QString Timestamp::fuzzyTime(QString isoTime)
 
                 if (timeDifference < 30) // less than a (average) month
                 {
-                    localTimeDateString = tr("About %1 days ago").arg(timeDifference);
+                    if (timeDifference == 1)
+                    {
+                        localTimeDateString = tr("A day ago");
+                    }
+                    else
+                    {
+                        localTimeDateString = tr("%1 days ago").arg(timeDifference);
+                    }
                 }
                 else
                 {
@@ -103,12 +122,27 @@ QString Timestamp::fuzzyTime(QString isoTime)
 
                     if (timeDifference < 12) // less than a year
                     {
-                        localTimeDateString = tr("About %1 months ago").arg(timeDifference);
+                        if (timeDifference == 1)
+                        {
+                            localTimeDateString = tr("A month ago");
+                        }
+                        else
+                        {
+                            localTimeDateString = tr("%1 months ago").arg(timeDifference);
+                        }
                     }
                     else
                     {
-                        localTimeDateString = tr("More than a year ago");
-                        // FIXME: be specific with years, maybe
+                        timeDifference /= 12;
+
+                        if (timeDifference == 1)
+                        {
+                            localTimeDateString = tr("A year ago");
+                        }
+                        else
+                        {
+                            localTimeDateString = tr("%1 years ago").arg(timeDifference);
+                        }
                     }
                 }
             }
@@ -117,7 +151,7 @@ QString Timestamp::fuzzyTime(QString isoTime)
     // No, I'm not particularly proud of this code.... oh, well...
 
 
-    qDebug() << "Posted:" << localTimeDateString;
+    //qDebug() << "Posted:" << localTimeDateString;
 
 
     return localTimeDateString;
