@@ -72,105 +72,127 @@
 <context>
     <name>Commenter</name>
     <message>
-        <location filename="../src/commenter.cpp" line="40"/>
+        <location filename="../src/commenter.cpp" line="38"/>
+        <source>All</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/commenter.cpp" line="39"/>
+        <source>Show all the comments</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/commenter.cpp" line="52"/>
         <source>&amp;Comment</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../src/commenter.cpp" line="58"/>
+        <source>C&amp;ancel</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Composer</name>
     <message>
-        <location filename="../src/composer.cpp" line="30"/>
+        <location filename="../src/composer.cpp" line="35"/>
         <source>Type a message here to post it</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/composer.cpp" line="34"/>
+        <location filename="../src/composer.cpp" line="38"/>
         <source>Click here or press Control+N to post a note...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/composer.cpp" line="39"/>
+        <location filename="../src/composer.cpp" line="43"/>
         <source>Normal</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/composer.cpp" line="43"/>
+        <location filename="../src/composer.cpp" line="47"/>
         <source>Bold</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/composer.cpp" line="47"/>
+        <location filename="../src/composer.cpp" line="51"/>
         <source>Italic</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/composer.cpp" line="51"/>
+        <location filename="../src/composer.cpp" line="55"/>
         <source>Bold + Italic</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/composer.cpp" line="55"/>
+        <location filename="../src/composer.cpp" line="59"/>
         <source>Underline</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/composer.cpp" line="60"/>
+        <location filename="../src/composer.cpp" line="64"/>
         <source>Make a link</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/composer.cpp" line="71"/>
+        <location filename="../src/composer.cpp" line="75"/>
         <source>Cancel Post</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/composer.cpp" line="75"/>
+        <location filename="../src/composer.cpp" line="79"/>
         <source>&amp;F</source>
         <comment>F for formatting, translate accordingly</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/composer.cpp" line="77"/>
+        <location filename="../src/composer.cpp" line="81"/>
         <source>Text Formatting Options</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/composer.cpp" line="260"/>
+        <location filename="../src/composer.cpp" line="90"/>
+        <source>Type a comment here.
+You can press Control+Enter to send the comment
+with the keyboard, or ESC to cancel.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/composer.cpp" line="277"/>
         <source>Insert a link</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/composer.cpp" line="261"/>
+        <location filename="../src/composer.cpp" line="278"/>
         <source>Type or paste a web address here.
 </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/composer.cpp" line="269"/>
+        <location filename="../src/composer.cpp" line="286"/>
         <source>Make a link from selected text</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/composer.cpp" line="270"/>
+        <location filename="../src/composer.cpp" line="287"/>
         <source>Type or paste a web address here.
 The selected text (%1) will be converted to a link.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/composer.cpp" line="305"/>
-        <location filename="../src/composer.cpp" line="314"/>
+        <location filename="../src/composer.cpp" line="322"/>
+        <location filename="../src/composer.cpp" line="331"/>
         <source>Insert and image from a URL</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/composer.cpp" line="306"/>
+        <location filename="../src/composer.cpp" line="323"/>
         <source>Type or paste the image address here.
 </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/composer.cpp" line="315"/>
+        <location filename="../src/composer.cpp" line="332"/>
         <source>Type or paste the image address here.
 The selected text (%1) will be used as description.</source>
         <translation type="unfinished"></translation>
@@ -292,12 +314,17 @@ The selected text (%1) will be used as description.</source>
 <context>
     <name>ContactCard</name>
     <message>
-        <location filename="../src/contactcard.cpp" line="90"/>
+        <location filename="../src/contactcard.cpp" line="79"/>
+        <source>Hometown</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/contactcard.cpp" line="120"/>
         <source>Follow</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/contactcard.cpp" line="94"/>
+        <location filename="../src/contactcard.cpp" line="129"/>
         <source>Stop following</source>
         <translation type="unfinished"></translation>
     </message>
@@ -314,6 +341,24 @@ The selected text (%1) will be used as description.</source>
         <source>&amp;Follow</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../src/contactlist.cpp" line="90"/>
+        <source>Followin&amp;g</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/contactlist.cpp" line="93"/>
+        <source>Follo&amp;wers</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ImageViewer</name>
+    <message>
+        <location filename="../src/imageviewer.cpp" line="34"/>
+        <source>Image</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainWindow</name>
@@ -323,129 +368,175 @@ The selected text (%1) will be used as description.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="144"/>
+        <location filename="../src/mainwindow.cpp" line="143"/>
         <source>&amp;Timeline</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="144"/>
+        <source>The main timeline</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="147"/>
+        <source>Activity</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="148"/>
+        <source>Your own posts</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="151"/>
+        <source>Favorites</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="152"/>
+        <source>Your favorited posts</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="155"/>
         <source>&amp;Messages</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="150"/>
+        <location filename="../src/mainwindow.cpp" line="156"/>
+        <source>Messages sent explicitly to you</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="159"/>
         <source>&amp;Contacts</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="242"/>
+        <location filename="../src/mainwindow.cpp" line="160"/>
+        <source>The people you follow, and the ones who follow you</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="261"/>
         <source>Initializing...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="348"/>
+        <location filename="../src/mainwindow.cpp" line="367"/>
         <source>&amp;Session</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="351"/>
+        <location filename="../src/mainwindow.cpp" line="370"/>
         <source>&amp;Update Timelines</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="360"/>
+        <location filename="../src/mainwindow.cpp" line="379"/>
         <source>&amp;Post a Note</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="372"/>
+        <location filename="../src/mainwindow.cpp" line="391"/>
         <source>&amp;Quit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="381"/>
+        <location filename="../src/mainwindow.cpp" line="400"/>
         <source>&amp;View</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="384"/>
+        <location filename="../src/mainwindow.cpp" line="403"/>
         <source>View Side &amp;Panel</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="397"/>
+        <location filename="../src/mainwindow.cpp" line="416"/>
         <source>S&amp;ettings</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="400"/>
+        <location filename="../src/mainwindow.cpp" line="419"/>
         <source>&amp;Account Details</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="407"/>
+        <location filename="../src/mainwindow.cpp" line="426"/>
         <source>&amp;Configure Dianara</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="416"/>
+        <location filename="../src/mainwindow.cpp" line="435"/>
         <source>&amp;Help</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="419"/>
+        <location filename="../src/mainwindow.cpp" line="438"/>
         <source>Visit &amp;Website</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="425"/>
+        <location filename="../src/mainwindow.cpp" line="444"/>
         <source>About &amp;Dianara</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="436"/>
+        <location filename="../src/mainwindow.cpp" line="455"/>
         <source>&amp;Show Window</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="469"/>
+        <location filename="../src/mainwindow.cpp" line="488"/>
         <source>Your Pump.io account is not configured</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="498"/>
+        <location filename="../src/mainwindow.cpp" line="517"/>
         <source>[ Configure your account ]</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="666"/>
+        <location filename="../src/mainwindow.cpp" line="685"/>
         <source>Dianara notification</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="764"/>
+        <location filename="../src/mainwindow.cpp" line="775"/>
         <source>Timeline updated. There are %1 new posts.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="768"/>
+        <location filename="../src/mainwindow.cpp" line="779"/>
         <source>Timeline updated at %1.
 There are %2 new posts.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="774"/>
+        <location filename="../src/mainwindow.cpp" line="785"/>
         <source>Timeline updated. No new posts.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="889"/>
+        <location filename="../src/mainwindow.cpp" line="905"/>
         <source>About Dianara</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="896"/>
-        <source>Dianara is a pump.io social networking client.&lt;br&gt;&lt;br&gt;It is work in progress. Right now only the interface and some basic capabilities: posting text, showing timeline, linking/commenting/sharing/deleting posts, and contact listing.&lt;br&gt;&lt;br&gt;</source>
+        <location filename="../src/mainwindow.cpp" line="912"/>
+        <source>Dianara is a pump.io social networking client.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="914"/>
+        <source>With Dianara you can see your timeline, create new posts, like/comment/share/delete posts, see your contacts and follow new people.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="918"/>
+        <source>English translation by JanKusanagi.</source>
+        <comment>TRANSLATORS: Change this with your language and name ;)</comment>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -490,109 +581,120 @@ There are %2 new posts.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/post.cpp" line="122"/>
-        <source>using</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/post.cpp" line="131"/>
+        <location filename="../src/post.cpp" line="503"/>
         <source>Like</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/post.cpp" line="132"/>
+        <location filename="../src/post.cpp" line="502"/>
         <source>Like this post</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/post.cpp" line="138"/>
+        <location filename="../src/post.cpp" line="122"/>
+        <source>Posted on %1, using %2</source>
+        <comment>1=Date, 2=Program used</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/post.cpp" line="227"/>
         <source>Comment</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/post.cpp" line="139"/>
+        <location filename="../src/post.cpp" line="228"/>
         <source>Comment on this post</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/post.cpp" line="144"/>
+        <location filename="../src/post.cpp" line="233"/>
         <source>Share</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/post.cpp" line="145"/>
+        <location filename="../src/post.cpp" line="234"/>
         <source>Share this post</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/post.cpp" line="168"/>
+        <location filename="../src/post.cpp" line="138"/>
         <source>Reshared post</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/post.cpp" line="187"/>
+        <location filename="../src/post.cpp" line="163"/>
         <source>%1 likes</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/post.cpp" line="197"/>
+        <location filename="../src/post.cpp" line="175"/>
         <source>%1 comments</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/post.cpp" line="208"/>
+        <location filename="../src/post.cpp" line="187"/>
         <source>%1 shares</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/post.cpp" line="246"/>
+        <location filename="../src/post.cpp" line="254"/>
         <source>Delete</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/post.cpp" line="247"/>
+        <location filename="../src/post.cpp" line="255"/>
         <source>Delete this post</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/post.cpp" line="303"/>
+        <location filename="../src/post.cpp" line="318"/>
         <source>This post has been marked Not Safe For Work (#NSFW).
 Click here to show it.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/post.cpp" line="426"/>
+        <location filename="../src/post.cpp" line="496"/>
+        <source>You like this</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/post.cpp" line="497"/>
+        <source>Unlike</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/post.cpp" line="548"/>
         <source>Share post?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/post.cpp" line="427"/>
+        <location filename="../src/post.cpp" line="549"/>
         <source>Do you want to share %1&apos;s post?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/post.cpp" line="428"/>
+        <location filename="../src/post.cpp" line="550"/>
         <source>&amp;Yes, share it</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/post.cpp" line="428"/>
-        <location filename="../src/post.cpp" line="451"/>
+        <location filename="../src/post.cpp" line="550"/>
+        <location filename="../src/post.cpp" line="573"/>
         <source>&amp;No</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/post.cpp" line="449"/>
+        <location filename="../src/post.cpp" line="571"/>
         <source>Delete post?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/post.cpp" line="450"/>
+        <location filename="../src/post.cpp" line="572"/>
         <source>Are you sure you want to delete this post?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/post.cpp" line="451"/>
+        <location filename="../src/post.cpp" line="573"/>
         <source>&amp;Yes, delete it</source>
         <translation type="unfinished"></translation>
     </message>
@@ -600,57 +702,93 @@ Click here to show it.</source>
 <context>
     <name>Publisher</name>
     <message>
-        <location filename="../src/publisher.cpp" line="35"/>
-        <source>Public</source>
+        <location filename="../src/publisher.cpp" line="43"/>
+        <source>Title for the picture (optional)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/publisher.cpp" line="36"/>
-        <source>Followers</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/publisher.cpp" line="38"/>
-        <source>List 1</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/publisher.cpp" line="39"/>
-        <source>List 2</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/publisher.cpp" line="40"/>
-        <source>List 3</source>
+        <location filename="../src/publisher.cpp" line="44"/>
+        <source>Title for the picture</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/publisher.cpp" line="48"/>
+        <source>Select Picture...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/publisher.cpp" line="51"/>
+        <source>Find the picture in your folders</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/publisher.cpp" line="69"/>
+        <source>Public</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/publisher.cpp" line="70"/>
+        <source>Followers</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/publisher.cpp" line="84"/>
+        <source>Add &amp;Picture</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/publisher.cpp" line="85"/>
+        <source>Upload photo</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/publisher.cpp" line="167"/>
+        <source>Picture not set</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/publisher.cpp" line="287"/>
+        <source>Select one image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/publisher.cpp" line="289"/>
+        <source>Image files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/publisher.cpp" line="290"/>
+        <source>All files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/publisher.cpp" line="314"/>
+        <source>Invalid image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/publisher.cpp" line="315"/>
+        <source>The image format cannot be detected.
+The extension might be wrong, like a GIF image renamed to image.jpg or similar.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/publisher.cpp" line="78"/>
         <source>&amp;To...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/publisher.cpp" line="49"/>
+        <location filename="../src/publisher.cpp" line="79"/>
         <source>Select who will see this post</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/publisher.cpp" line="54"/>
-        <source>&amp;Picture...</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/publisher.cpp" line="55"/>
-        <source>Upload photos</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/publisher.cpp" line="59"/>
+        <location filename="../src/publisher.cpp" line="91"/>
         <source>&amp;Post</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/publisher.cpp" line="60"/>
+        <location filename="../src/publisher.cpp" line="92"/>
         <source>Hit Control+Enter to post with the keyboard</source>
         <translation type="unfinished"></translation>
     </message>
@@ -658,62 +796,102 @@ Click here to show it.</source>
 <context>
     <name>PumpController</name>
     <message>
-        <location filename="../src/pumpcontroller.cpp" line="209"/>
-        <source>Getting contact list...</source>
+        <location filename="../src/pumpcontroller.cpp" line="232"/>
+        <source>Getting followed list...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpcontroller.cpp" line="232"/>
+        <location filename="../src/pumpcontroller.cpp" line="238"/>
+        <source>Getting followers list...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/pumpcontroller.cpp" line="255"/>
         <source>Getting timeline...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpcontroller.cpp" line="380"/>
+        <location filename="../src/pumpcontroller.cpp" line="288"/>
+        <source>Getting likes...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/pumpcontroller.cpp" line="313"/>
+        <source>Getting comments...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/pumpcontroller.cpp" line="459"/>
+        <source>Error connecting to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/pumpcontroller.cpp" line="472"/>
         <source>Post published successfully.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpcontroller.cpp" line="384"/>
+        <location filename="../src/pumpcontroller.cpp" line="476"/>
         <source>Post liked successfully.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpcontroller.cpp" line="388"/>
+        <location filename="../src/pumpcontroller.cpp" line="480"/>
         <source>Comment posted successfully.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpcontroller.cpp" line="392"/>
+        <location filename="../src/pumpcontroller.cpp" line="484"/>
         <source>Post shared successfully.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpcontroller.cpp" line="396"/>
+        <location filename="../src/pumpcontroller.cpp" line="488"/>
         <source>Post deleted successfully.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpcontroller.cpp" line="400"/>
+        <location filename="../src/pumpcontroller.cpp" line="492"/>
         <source>Following successfully.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpcontroller.cpp" line="407"/>
+        <location filename="../src/pumpcontroller.cpp" line="499"/>
         <source>Stopped following successfully.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpcontroller.cpp" line="493"/>
+        <location filename="../src/pumpcontroller.cpp" line="586"/>
         <source>Timeline received. Updating post list...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpcontroller.cpp" line="535"/>
-        <source>Contact list received.</source>
+        <location filename="../src/pumpcontroller.cpp" line="614"/>
+        <source>Likes received.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpcontroller.cpp" line="758"/>
+        <location filename="../src/pumpcontroller.cpp" line="640"/>
+        <source>Comments received.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/pumpcontroller.cpp" line="672"/>
+        <source>File uploaded succesfully. Posting message...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/pumpcontroller.cpp" line="715"/>
+        <source>Followed list received.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/pumpcontroller.cpp" line="720"/>
+        <source>Followers list received.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/pumpcontroller.cpp" line="948"/>
         <source>Ready.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -721,17 +899,17 @@ Click here to show it.</source>
 <context>
     <name>TimeLine</name>
     <message>
-        <location filename="../src/timeline.cpp" line="51"/>
+        <location filename="../src/timeline.cpp" line="53"/>
         <source>&amp;First Page</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/timeline.cpp" line="54"/>
+        <location filename="../src/timeline.cpp" line="56"/>
         <source>&amp;Previous Page</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/timeline.cpp" line="57"/>
+        <location filename="../src/timeline.cpp" line="59"/>
         <source>&amp;Next Page</source>
         <translation type="unfinished"></translation>
     </message>
@@ -739,33 +917,58 @@ Click here to show it.</source>
 <context>
     <name>Timestamp</name>
     <message>
-        <location filename="../src/timestamp.cpp" line="75"/>
+        <location filename="../src/timestamp.cpp" line="73"/>
         <source>Less than a minute ago</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/timestamp.cpp" line="82"/>
+        <source>A minute ago</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/timestamp.cpp" line="86"/>
         <source>%1 minutes ago</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/timestamp.cpp" line="90"/>
-        <source>About %1 hours ago</source>
+        <location filename="../src/timestamp.cpp" line="97"/>
+        <source>An hour ago</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/timestamp.cpp" line="98"/>
-        <source>About %1 days ago</source>
+        <location filename="../src/timestamp.cpp" line="101"/>
+        <source>%1 hours ago</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/timestamp.cpp" line="106"/>
-        <source>About %1 months ago</source>
+        <location filename="../src/timestamp.cpp" line="112"/>
+        <source>A day ago</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/timestamp.cpp" line="110"/>
-        <source>More than a year ago</source>
+        <location filename="../src/timestamp.cpp" line="116"/>
+        <source>%1 days ago</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/timestamp.cpp" line="127"/>
+        <source>A month ago</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/timestamp.cpp" line="131"/>
+        <source>%1 months ago</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/timestamp.cpp" line="140"/>
+        <source>A year ago</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/timestamp.cpp" line="144"/>
+        <source>%1 years ago</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
